@@ -9,12 +9,15 @@ print.summary.meta <- function(x,
                                header = TRUE,
                                backtransf = x$backtransf,
                                pscale = x$pscale,
+                               irscale = x$irscale,
+                               irunit = x$irunit,
                                bylab.nchar = 35,
                                digits.zval = .settings$digits.zval,
                                digits.Q = .settings$digits.Q,
                                digits.tau2 = .settings$digits.tau2,
                                digits.H = .settings$digits.H,
                                digits.I2 = .settings$digits.I2,
+                               warn.backtransf = FALSE,
                                ...) {
   
   
@@ -43,7 +46,10 @@ print.summary.meta <- function(x,
   chknumeric(digits.H, min = 0, single = TRUE)
   chknumeric(digits.I2, min = 0, single = TRUE)
   chklogical(backtransf)
-  if (!(x$sm %in% c("PLOGIT", "PLN", "PRAW", "PAS", "PFT")))
+  is.prop <- x$sm %in% c("PLOGIT", "PLN", "PRAW", "PAS", "PFT")
+  is.rate <- x$sm %in% c("IR", "IRLN", "IRS", "IRFT")
+  ##
+  if (!is.prop)
     pscale <- 1
   if (!is.null(pscale))
     chknumeric(pscale, single = TRUE)
@@ -53,6 +59,16 @@ print.summary.meta <- function(x,
     warning("Argument 'pscale' set to 1 as argument 'backtransf' is FALSE.")
     pscale <- 1
   }
+  if (!is.rate)
+    irscale <- 1
+  if (!is.null(irscale))
+    chknumeric(irscale, single = TRUE)
+  else
+    irscale <- 1
+  if (!backtransf & irscale != 1) {
+    warning("Argument 'irscale' set to 1 as argument 'backtransf' is FALSE.")
+    irscale <- 1
+  }
   chklogical(comb.fixed)
   chklogical(comb.random)
   chklogical(prediction)
@@ -110,14 +126,20 @@ print.summary.meta <- function(x,
   if (backtransf) {
     if (sm == "ZCOR")
       sm.lab <- "COR"
-    else if (sm %in% c("PLOGIT", "PLN", "PRAW", "PAS", "PFT")) {
+    else if (is.prop) {
       if (pscale == 1)
         sm.lab <- "proportion"
       else
         sm.lab <- "events"
     }
+    else if (is.rate) {
+      if (irscale == 1)
+        sm.lab <- "rate"
+      else
+        sm.lab <- "events"
+    }
   }
-  else 
+  else
     if (is.relative.effect(sm))
       sm.lab <- paste("log", sm, sep = "")
   ##
@@ -158,7 +180,7 @@ print.summary.meta <- function(x,
     lowTE.fixed.w  <- x$within.fixed$lower
     uppTE.fixed.w  <- x$within.fixed$upper
     pval.fixed.w   <- x$within.fixed$p
-    n.harmonic.mean.w <- x$within.fixed$harmonic.mean
+    harmonic.mean.w <- x$within.fixed$harmonic.mean
     TE.random.w    <- x$within.random$TE
     lowTE.random.w <- x$within.random$lower
     uppTE.random.w <- x$within.random$upper
@@ -171,70 +193,76 @@ print.summary.meta <- function(x,
     ##
     Q.w <- x$Q.w
   }
-  ##  
+  ##
   if (backtransf) {
-    npft.ma <- 1 / mean(1 / x$n)
+    if (inherits(x, "metarate"))
+      harmonic.mean <- 1 / mean(1 / x$time)
+    else
+      harmonic.mean <- 1 / mean(1 / x$n)
     ##
     TE.fixed    <- backtransf(TE.fixed, sm, "mean",
-                              npft.ma, warn = comb.fixed)
+                              harmonic.mean, warn = comb.fixed & warn.backtransf)
     lowTE.fixed <- backtransf(lowTE.fixed, sm, "lower",
-                              npft.ma, warn = comb.fixed)
+                              harmonic.mean, warn = comb.fixed & warn.backtransf)
     uppTE.fixed <- backtransf(uppTE.fixed, sm, "upper",
-                              npft.ma, warn = comb.fixed)
+                              harmonic.mean, warn = comb.fixed & warn.backtransf)
     ##
     TE.random <- backtransf(TE.random, sm, "mean",
-                            npft.ma, warn = comb.random)
+                            harmonic.mean, warn = comb.random & warn.backtransf)
     lowTE.random <- backtransf(lowTE.random, sm, "lower",
-                               npft.ma, warn = comb.random)
+                               harmonic.mean, warn = comb.random & warn.backtransf)
     uppTE.random <- backtransf(uppTE.random, sm, "upper",
-                               npft.ma, warn = comb.random)
+                               harmonic.mean, warn = comb.random & warn.backtransf)
     ##
     lowTE.predict <- backtransf(lowTE.predict, sm, "lower",
-                                npft.ma, warn = prediction)
+                                harmonic.mean, warn = prediction & warn.backtransf)
     uppTE.predict <- backtransf(uppTE.predict, sm, "upper",
-                                npft.ma, warn = prediction)
+                                harmonic.mean, warn = prediction & warn.backtransf)
     ##
     if (by) {
-      npft.w <- n.harmonic.mean.w
-      ##
       TE.fixed.w     <- backtransf(TE.fixed.w, sm, "mean",
-                                   npft.w, warn = comb.fixed)
+                                   harmonic.mean.w, warn = comb.fixed & warn.backtransf)
       lowTE.fixed.w  <- backtransf(lowTE.fixed.w, sm, "lower",
-                                   npft.w, warn = comb.fixed)
+                                   harmonic.mean.w, warn = comb.fixed & warn.backtransf)
       uppTE.fixed.w  <- backtransf(uppTE.fixed.w, sm, "upper",
-                                   npft.w, warn = comb.fixed)
+                                   harmonic.mean.w, warn = comb.fixed & warn.backtransf)
       ##
       TE.random.w    <- backtransf(TE.random.w, sm, "mean",
-                                   npft.w, warn = comb.random)
+                                   harmonic.mean.w, warn = comb.random & warn.backtransf)
       lowTE.random.w <- backtransf(lowTE.random.w, sm, "lower",
-                                   npft.w, warn = comb.random)
+                                   harmonic.mean.w, warn = comb.random & warn.backtransf)
       uppTE.random.w <- backtransf(uppTE.random.w, sm, "upper",
-                                   npft.w, warn = comb.random)
+                                   harmonic.mean.w, warn = comb.random & warn.backtransf)
     }
   }
   ##
-  ## Apply argument 'pscale' to proportions
+  ## Apply argument 'pscale' to proportions and 'irscale' to rates
   ##
-  if (sm %in% c("PLOGIT", "PLN", "PRAW", "PAS", "PFT")) {
-    TE.fixed    <- pscale * TE.fixed
-    lowTE.fixed <- pscale * lowTE.fixed
-    uppTE.fixed <- pscale * uppTE.fixed
+  if (is.prop | is.rate) {
+    if (is.prop)
+      scale <- pscale
+    else if (is.rate)
+      scale <- irscale
     ##
-    TE.random    <- pscale * TE.random
-    lowTE.random <- pscale * lowTE.random
-    uppTE.random <- pscale * uppTE.random
+    TE.fixed    <- scale * TE.fixed
+    lowTE.fixed <- scale * lowTE.fixed
+    uppTE.fixed <- scale * uppTE.fixed
     ##
-    lowTE.predict <- pscale * lowTE.predict
-    uppTE.predict <- pscale * uppTE.predict
+    TE.random    <- scale * TE.random
+    lowTE.random <- scale * lowTE.random
+    uppTE.random <- scale * uppTE.random
+    ##
+    lowTE.predict <- scale * lowTE.predict
+    uppTE.predict <- scale * uppTE.predict
     ##
     if (by) {
-      TE.fixed.w    <- pscale * TE.fixed.w
-      lowTE.fixed.w <- pscale * lowTE.fixed.w
-      uppTE.fixed.w <- pscale * uppTE.fixed.w
+      TE.fixed.w    <- scale * TE.fixed.w
+      lowTE.fixed.w <- scale * lowTE.fixed.w
+      uppTE.fixed.w <- scale * uppTE.fixed.w
       ##   
-      TE.random.w    <- pscale * TE.random.w
-      lowTE.random.w <- pscale * lowTE.random.w
-      uppTE.random.w <- pscale * uppTE.random.w
+      TE.random.w    <- scale * TE.random.w
+      lowTE.random.w <- scale * lowTE.random.w
+      uppTE.random.w <- scale * uppTE.random.w
     }
   }
   ##
@@ -314,7 +342,9 @@ print.summary.meta <- function(x,
             sd.glass = x$sd.glass,
             exact.smd = x$exact.smd,
             model.glmm = x$model.glmm,
-            pscale = pscale)
+            pscale = pscale,
+            irscale = irscale,
+            irunit = irunit)
   }
   else {
     ##
@@ -543,7 +573,9 @@ print.summary.meta <- function(x,
             sd.glass = x$sd.glass,
             exact.smd = x$exact.smd,
             model.glmm = x$model.glmm,
-            pscale = pscale)
+            pscale = pscale,
+            irscale = irscale,
+            irunit = irunit)
   }
   
   
